<?php
/**
 * Class SGC_Events
 * All class methods for creating the custom post type sgc_event
 * 
 * @author Matthew Linton
 *
 */
class SGC_Events
{
    /**
     * 
     */
    public function create_post_type_events() {
        $labels = array(
            'name' => 'Events',
            'singular_name' => 'Event',
            'add_new' => 'Add New Event',
            'add_new_item' => 'Add New Event',
            'edit_item' => 'Edit Event',
            'new_item' => 'New Event',
            'all_items' => 'All Events',
            'view_item' => 'View Event',
            'search_items' => 'Search Events',
            'not_found' =>  'No Events Found',
            'not_found_in_trash' => 'No Events found in Trash',
            'parent_item_colon' => '',
            'menu_name' => 'Events'
        );
        
        register_post_type( 'sgc_event', array(
            'labels' => $labels,
            'has_archive' => true,
            'public' => true,
            'show_in_rest' => true,
            'rest_base' => 'sgc_events',
            'supports' => array( 'title', 'editor', 'thumbnail', 'comments' ),
            'taxonomies' => array( '' ),
            'exclude_from_search' => false,
            'capability_type' => 'post',
            'rewrite' => array( 'slug' => 'sgc_events' ),
            'menu_icon' => 'dashicons-tickets-alt'
        ));
    }
    
    /**
     * 
     */
    public function add_event_rest() {
        register_rest_route( 'simplegolfclub/v1', '/event/players/(?P<id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Events', 'get_rest_event_players'),
        ) );
        register_rest_route( 'simplegolfclub/v1', '/event/groups/(?P<id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Events', 'get_rest_event_groups'),
        ) );
        register_rest_route( 'simplegolfclub/v1', '/event/checkin/(?P<id>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Events', 'get_rest_event_checkin'),
        ) );
        register_rest_route( 'simplegolfclub/v1', '/event/checkin/(?P<id>\d+)/(?P<pid>\d+)', array(
            'methods' => 'GET',
            'callback' => array('SGC_Events', 'toggle_rest_event_checkin'),
        ) );
    }

    /**
     * 
     */
    public function add_event_fields( $posts ) {
        add_meta_box(
            'sgc_custom_event_fields',
            'Event Details',
            array('SGC_Events', 'event_fields_html'),
            'sgc_event',
            'side'
            );
    }
    
    /**
     * 
     */
    public function event_fields_html($posts) {
        global $wpdb, $post;
        
        $default_team = get_option('sgc_defaultteam');
        $default_location = get_option('sgc_defaultlocation');
        
        $event_date = get_post_meta($post->ID, 'sgc_eventdate', true);
        $event_time = get_post_meta($post->ID, 'sgc_eventtime', true);
        $event_location = get_post_meta($post->ID, 'sgc_eventlocation', true);
        $event_team = get_post_meta($post->ID, 'sgc_eventteam', true);
        $event_groups = get_post_meta($post->ID, 'sgc_eventgroups', true);
        
        if (!$event_team || $event_team == '' ) {
            $event_team = $default_team;
        }
        
        if (!$event_location || $event_location == '' ) {
            $event_location = $default_location;
        }
        
        // fetch all locations list
        $locations = get_posts(array(
            'post_type' => 'sgc_location',
            'post_status' => 'publish',
            'orderby'    => 'post_title',
            'sort_order' => 'asc',
            'posts_per_page' => -1
        ));
        
        // fetch all teams list
        $teams = get_posts(array(
            'post_type' => 'sgc_team',
            'post_status' => 'publish',
            'orderby'    => 'post_title',
            'sort_order' => 'asc',
            'posts_per_page' => -1
        ));
        
        include_once( plugin_dir_path( __FILE__ ) . '../admin/partials/sgc-admin-events.php' );
    }
    
    /**
     * 
     */
    public function save_event_meta($post_id)
    {
        if (array_key_exists('sgc_eventdate', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_eventdate',
                $_POST['sgc_eventdate']
                );
        }
        
        if (array_key_exists('sgc_eventtime', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_eventtime',
                $_POST['sgc_eventtime']
                );
        }
        
        if (array_key_exists('sgc_eventlocation', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_eventlocation',
                $_POST['sgc_eventlocation']
                );
        }
        
        if (array_key_exists('sgc_eventteam', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_eventteam',
                $_POST['sgc_eventteam']
                );
        }
        
        if (array_key_exists('sgc_eventgroups', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_eventgroups',
                $_POST['sgc_eventgroups']
                );
        }
    }
    
    /**
     * 
     */
    public function get_rest_event_players( $data ) {
        $event_team = get_post_meta( $data['id'], 'sgc_eventteam', true);
        
        // fetch player list
        $posts = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_playerteam',
                    'value' => $event_team
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_player',
            'orderby' => 'post_title',
            'order' => 'ASC',
            'posts_per_page' => -1
        ));
        
        if ( empty( $posts ) ) { return null; }
        return wp_send_json($posts);
    }
    
    /**
     * 
     */
    public function get_rest_event_groups( $data ) {
        $groups = get_post_meta( $data['id'], 'sgc_eventgroups', true );
        
        if ( empty( $groups ) ) { return null; }
        return wp_send_json( $groups );
    }
    
    /**
     * 
     */
    public function get_rest_event_checkin( $data ) {
        $checkin = get_post_meta( $data['id'], 'sgc_eventcheckin', true);
        
        if ( empty( $checkin ) ) { return null; }
        return wp_send_json( $checkin );
    }
    
    /**
     * 
     */
    public function toggle_rest_event_checkin ( $data ) {
        $eventid = $data['id'];
        $playerid = $data['pid'];
        
        // make sure the event and player exist. exit early if false
        if ( FALSE === get_post_status( $eventid ) ) { return 'Event does not exist'; }
        if ( FALSE === get_post_status( $playerid ) ) { return 'Player does not exist'; }
        
        $checkin = json_decode( get_post_meta( $eventid, 'sgc_eventcheckin', true) );
        
        if ( $checkin == 'null' || $checkin == null ) { $checkin = []; }
        $event_team = get_post_meta($eventid, 'sgc_eventteam', true);
        
        //get list of players for the event team
        $players = get_posts(array(
            'meta_query' => array(
                array(
                    'key' => 'sgc_playerteam',
                    'value' => $event_team
                )
            ),
            'post_status' => 'publish',
            'post_type' => 'sgc_player',
            'orderby' => 'post_title',
            'order' => 'ASC',
            'posts_per_page' => -1
        ));
        
        // Verify that the playerID passed matches one from the event team
        $isplayer = false;
        foreach ( $players as $player ) {
            if ( $player->ID == $playerid ) { $isplayer = true; }
        }
        
        if ( $isplayer == true ) {
            // check to see if the player is checked in and remove them
            $ischeckedin = false;
            for ( $i = 0 ; $i < count( $checkin ) ; $i++ ) {
                if ( $checkin[$i] == $playerid ) {
                    $ischeckedin = true;
                    array_splice($checkin, $i, 1);
                }
            }
            
            // If the player is not checkedin add them
            if ( $ischeckedin == false ) {
                array_push( $checkin, $playerid );
            }
            
            //update the Event checkedin array
            update_post_meta( $eventid, 'sgc_eventcheckin', json_encode( $checkin ) );
        }
        return $checkin;
    }
    /**
     * 
     */
    public function add_comments( $data ) {
        if( $data['post_type'] == 'sgc_event' ) {
            $data['comment_status'] = 'open';
        }
        return $data;
    }
    
    /**
     * 
     */
    public function event_header( $eventid ) {
        $event_date = get_post_meta($eventid, 'sgc_eventdate', true);
        $event_time = get_post_meta($eventid, 'sgc_eventtime', true);
        $event_location = get_post_meta($eventid, 'sgc_eventlocation', true);
        $event_team = get_post_meta($eventid, 'sgc_eventteam', true);

        // Fetch the team for this event
        $team = get_post($event_team);
        $event_teamname = $team->post_title;
        $event_teamlink = get_permalink( $team->ID );

        // Fetch the location for this event
        $location = get_post( $event_location );
        $event_locationname = $location->post_title;
        $event_locationlink = get_permalink( $location->ID );
        
        // Set up event header defaults
        $event_header_date = _('TBD');
        $event_header_team = _('TBD');
        $event_header_location = _('TBD');
        
        if ( $event_date && $event_time ) {
            $event_header_date = $event_date . " @ " . $event_time;
        } elseif ( $event_date && ! $event_time ) {
            $event_header_date = $event_date;
        }
        
        if ( $event_teamname ) {
            $event_header_team = '<a href="' . $event_teamlink . '">' . $event_teamname . '</a>';
        } else {
            $event_header_team = _('TBD');
        }
        
        if ( $event_location ) {
            $event_header_location = '<a href="' . $event_locationlink . '">' . $event_locationname . '</a>';
        }
        
        include_once( plugin_dir_path( __FILE__ ) . '../public/partials/sgc-public-event_header.php' );
    }
    
    /**
     * 
     */
    public function event_content ( $postid, $content ) {
        if ( is_single() ) {
            self::event_header( $postid );
            $content =  wpautop($content)
                    . '<input type="hidden" id="sgc_javascript" value="sgc_event">'
                    . '<input type="hidden" id="sgc_eventid" value="' . $postid . '">'
                    . '<div class="sgc_eventgroups" id="sgc_eventgroups"></div>'
                    . '<div class=sgc_eventcheckin" id="sgc_eventcheckin"></div>'
                    . '<div class=sgc_eventscores" id="sgc_eventscores"></div>';
        } else {
            self::event_header( $postid );
        }
            
        return $content;
    }
}
