<?php

/**
 * 
 * @author Matthew Linton
 *
 */
class SGC_ScoreCards
{
    /**
     * 
     */
    public function create_post_type_scorecards() {
        $labels = array(
            'name' => 'Score Cards',
            'singular_name' => 'Score Card',
            'add_new' => 'Add New Score Card',
            'add_new_item' => 'Add New Score Card',
            'edit_item' => 'Edit Score Card',
            'new_item' => 'New Score Card',
            'all_items' => 'All Score Card',
            'view_item' => 'View Score Card',
            'search_items' => 'Search Score Card',
            'not_found' =>  'No Score Card Found',
            'not_found_in_trash' => 'No Score Card found in Trash',
            'parent_item_colon' => '',
            'menu_name' => 'Score Cards'
        );
        
        register_post_type( 'sgc_scorecard', array(
            'labels' => $labels,
            'has_archive' => true,
            'public' => true,
            'supports' => array( 'title', 'editor' ),
            'taxonomies' => array(''),
            'exclude_from_search' => false,
            'capability_type' => 'post',
            'rewrite' => array( 'slug' => 'sgc_scorecards' ),
            'menu_icon' => 'dashicons-list-view'
        ));
    }
    
    /**
     *
     */
    public function disable_auto_save_posts() {
        switch(get_post_type()) {
            case 'scg_scorecard':
                wp_dequeue_script('autosave');
                break;
        }
    }
    
    /**
     *
     */
    public function add_scorecards_fields() {
        add_meta_box(
            'sgc_custom_scorecard_fields',           // Unique ID
            'Score Card',  // Box title
            array('SGC_ScoreCards', 'scorecards_fields_html'),
            'sgc_scorecard',
            'normal',
            'high'
            );
    }
    
    /**
     *
     */
    public function scorecards_fields_html() {
        global $wpdb, $post;
        
        $scorecard_event = get_post_meta($post->ID, 'sgc_scorecardevent', true);
        $scorecard_player = get_post_meta($post->ID, 'sgc_scorecardplayer', true);
        $scorecard_team = -1;
        
        // fetch events list
        $events = get_posts(array(
            'post_type' => 'sgc_event',
            'post_status' => 'publish',
            'orderby'    => 'post_date',
            'sort_order' => 'desc',
            'posts_per_page' => 32
        ));
        
        if ( $scorecard_event > 0) {
            $scorecard_team = get_post_meta($scorecard_event, 'sgc_eventteam', true);
        }
        
        if ($scorecard_team > 0) {
            $players = get_posts(array(
                'post_type' => 'sgc_player',
                'post_status' => 'publish',
                'meta_query' => array(array('key' => 'sgc_playerteam', 'value' => $scorecard_team)),
                'orderby'    => 'post_title',
                'sort_order' => 'asc',
                'posts_per_page' => 32
            ));
        }
        
        include_once( plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/sgc-admin-scorecards.php' );
    }
    
    /**
     *
     */
    public function save_scorecards_meta($post_id)
    {
        if (array_key_exists('sgc_scorecardteam', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_scorecardteam',
                $_POST['sgc_scorecardteam']
                );
        }
        if (array_key_exists('sgc_scorecardplayer', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_scorecardplayer',
                $_POST['sgc_scorecardplayer']
                );
        }
        if (array_key_exists('sgc_scorecardevent', $_POST)) {
            update_post_meta(
                $post_id,
                'sgc_scorecardevent',
                $_POST['sgc_scorecardevent']
                );
        }
    }
}

